=====================
Configuration Options
=====================

This section provides a list of all possible options for each
configuration file.

Configuration Reference
-----------------------

networking-ovn uses the following configuration files for its various services.

.. toctree::
   :glob:
   :maxdepth: 1

   *

Sample Configuration Files
--------------------------

The following are sample configuration files for all networking-ovn.
These are generated from code and reflect the current state of code
in the networking-ovn repository.

.. toctree::
   :glob:
   :maxdepth: 1

   samples/*
